@@ -38,3 +38,6 @@ LOGS_PATH = "logs"
 PROOF_PATH = "db/proof/"
 
 EXTRACTED_PROOFS_PATH = "db/extracted_proofs/"
+
+QR_CODE_PATH = "db/qrs/"
+BACKUPS_PATH = "backups/"
