@@ -5,6 +5,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 from decentra_network.blockchain.block.block_main import Block
+from decentra_network.blockchain.block.save_block import SaveBlock
 from decentra_network.blockchain.candidate_block.candidate_block_main import \
     candidate_block
 from decentra_network.consensus.rounds.round_1.round_1_main import \
@@ -29,9 +30,21 @@ def ongoing_main(
     custom_TEMP_BLOCK_PATH: str = None,
     custom_TEMP_BLOCKSHASH_PATH: str = None,
     custom_TEMP_BLOCKSHASH_PART_PATH: str = None,
+    custom_shares=None,
+    custom_fee_address=None,
+    pass_sync=False
 ) -> Block:
 
-    if not block.round_1:
+    block.sync_empty_blocks() if pass_sync is False else None
+    SaveBlock(
+            block,
+            custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
+            custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
+            custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
+            custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
+        )    
+
+    if not block.round_1:    
         logger.debug("First round is starting")
         consensus_round_1(
             block,
@@ -43,6 +56,8 @@ def ongoing_main(
             custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
             custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
             custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
+            custom_shares=custom_shares,
+            custom_fee_address=custom_fee_address,
         )
         logger.debug("First round is done")
     elif not block.round_2:
