@@ -32,9 +32,11 @@ logger = get_logger("CONSENSUS_FIRST_ROUND")
 
 def find_validated(block: Block, candidate_class: candidate_block,
                    unl_nodes: dict) -> list:
+    logger.info("Finding process of validating list is started.")
     temp_validating_list = []
+    logger.debug(f"First temp_validating_list: {temp_validating_list}")
     for candidate_block in candidate_class.candidate_blocks[:]:
-        logger.debug(f"Candidate block {str(candidate_block)}")
+        logger.debug(f"Candidate block {candidate_block}")
 
         for other_block_tx in candidate_block["transaction"]:
 
@@ -52,19 +54,21 @@ def find_validated(block: Block, candidate_class: candidate_block,
             else:
                 tx_valid += 1
 
+
             logger.debug(
                 f"Tx valid of {other_block_tx.signature} : {tx_valid}")
-            if tx_valid > (len(unl_nodes) / 2):
+            if tx_valid > ((len(unl_nodes) + 1) / 2):
 
                 already_in_ok = False
                 for alrady_tx in temp_validating_list[:]:
 
                     if other_block_tx.signature == alrady_tx.signature:
-                        logger.warning(
+                        logger.debug(
                             "The transaction is already in the list")
                         already_in_ok = True
                 if not already_in_ok:
                     logger.debug(
                         f"Transaction is valid ({other_block_tx.signature})")
                     temp_validating_list.append(other_block_tx)
+    logger.debug(f"First temp_validating_list: {temp_validating_list}")
     return temp_validating_list
