@@ -11,6 +11,7 @@ from distutils.log import info
 
 from decentra_network.config import MY_TRANSACTION_PATH
 from decentra_network.lib.config_system import get_config
+from decentra_network.lib.notification import notification
 from decentra_network.transactions.my_transactions.get_my_transaction import \
     GetMyTransaction
 from decentra_network.transactions.my_transactions.save_my_transaction import \
@@ -28,6 +29,8 @@ def SendedTransaction(tx: Transaction,
         The list of the my transactions.
     """
 
+    notification("Sended TX", f"{tx.data}:{tx.amount} to {tx.toUser}")
+
     custom_currently_list = (GetMyTransaction()
                              if custom_currently_list is None else
                              custom_currently_list)
